==> nextcloud-27.1.11.tgz: nextcloud/apps/suspicious_login/l10n/pt_BR.js <==
OC.L10N.register(
    "suspicious_login",
    {
    "New login location detected" : "Novo local de login detectado",
    "You can get more info by pressing the button which will open %s and show info about the suspicious IP-address." : "Você pode obter mais informações pressionando o botão que irá abrir 1%s e mostrar informações sobre o endereço IP suspeito.",
    "A new login into your account was detected. The IP address %s was classified as suspicious. If this was you, you can ignore this message. Otherwise you should change your password." : "Um novo login na sua conta foi detectado. O endereço IP %s foi classificado como suspeito. Se era você, pode ignorar esta mensagem. Caso contrário, você deve alterar sua senha.",
    "More information ↗" : "Mais Informações ↗",
    "Suspicious Login" : "Logins Suspeitos",
    "New login detected" : "Novo login detectado",
    "Detect and warn about suspicious IPs logging into Nextcloud\n\t" : "Detectar e avisar sobre IPs suspeitos conectados ao Nextcloud\n\t",
    "Suspicious login detection" : "Detecção de login suspeito",
    "The suspicious login app is enabled on this instance. It will keep track of IP addresses users successfully log in from and build a classifier that warns if a new login comes from a suspicious IP address." : "O aplicativo de login suspeito está ativado nesta instância. Ele rastreará os endereços IP dos quais fizeram login e criará um classificador que avisa se um novo login vier de um endereço IP suspeito.",
    "Training data statistics" : "Estatísticas de dados de treinamento",
    "So far the app has captured {total} logins (including client connections), of which {distinct} are distinct (IP, UID) tuples." : "Até agora, o aplicativo capturou {total} logins (incluindo conexões de clientes), dos quais {distinct} são tuplas distintas (IP, UID).",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Classifier model statistics" : "Estatísticas do modelo do classificador",
    "No classifier model has been trained yet. This most likely means that you just enabled the app recently. Because the training of a model requires good data, the app waits until logins of at least {days} days have been captured." : "Nenhum modelo de classificador foi treinado ainda. Isso provavelmente significa que você ativou o aplicativo recentemente. Como o treinamento de um modelo requer bons dados, o aplicativo aguarda até que logins de pelo menos {days} dias sejam capturados.",
    "During evaluation, the latest model (trained {time}) has shown to capture {recall}% of all suspicious logins (recall), whereas {precision}% of the logins classified as suspicious are indeed suspicious (precision). Below you see a visualization of historic model performance." : "Durante a avaliação, o modelo mais recente (treinado {time}) mostrou capturar {recall}% de todos os logins suspeitos (recall), enquanto {precision}% dos logins classificados como suspeitos são realmente suspeitos (precisão). Abaixo você vê uma visualização do desempenho do modelo histórico.",
    "Precision" : "Precisão",
    "Recall" : "Recall"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-28.0.9.tgz: nextcloud/apps/suspicious_login/l10n/pt_BR.js <==
OC.L10N.register(
    "suspicious_login",
    {
    "New login location detected" : "Novo local de login detectado",
    "More info about the suspicious IP address available on %s" : "Mais informações sobre o endereço IP suspeito disponíveis em %s",
    "A new login into your account was detected. The IP address %s was classified as suspicious. If this was you, you can ignore this message. Otherwise you should change your password." : "Um novo login na sua conta foi detectado. O endereço IP %s foi classificado como suspeito. Se era você, pode ignorar esta mensagem. Caso contrário, você deve alterar sua senha.",
    "Open %s ↗" : "Abrir %s ↗",
    "Suspicious Login" : "Logins Suspeitos",
    "New login detected" : "Novo login detectado",
    "Detect and warn about suspicious IPs logging into Nextcloud\n\t" : "Detectar e avisar sobre IPs suspeitos conectados ao Nextcloud\n\t",
    "Suspicious login detection" : "Detecção de login suspeito",
    "The suspicious login app is enabled on this instance. It will keep track of IP addresses users successfully log in from and build a classifier that warns if a new login comes from a suspicious IP address." : "O aplicativo de login suspeito está ativado nesta instância. Ele rastreará os endereços IP dos quais fizeram login e criará um classificador que avisa se um novo login vier de um endereço IP suspeito.",
    "Training data statistics" : "Estatísticas de dados de treinamento",
    "So far the app has captured {total} logins (including client connections), of which {distinct} are distinct (IP, UID) tuples." : "Até agora, o aplicativo capturou {total} logins (incluindo conexões de clientes), dos quais {distinct} são tuplas distintas (IP, UID).",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Classifier model statistics" : "Estatísticas do modelo do classificador",
    "No classifier model has been trained yet. This most likely means that you just enabled the app recently. Because the training of a model requires good data, the app waits until logins of at least {days} days have been captured." : "Nenhum modelo de classificador foi treinado ainda. Isso provavelmente significa que você ativou o aplicativo recentemente. Como o treinamento de um modelo requer bons dados, o aplicativo aguarda até que logins de pelo menos {days} dias sejam capturados.",
    "During evaluation, the latest model (trained {time}) has shown to capture {recall}% of all suspicious logins (recall), whereas {precision}% of the logins classified as suspicious are indeed suspicious (precision). Below you see a visualization of historic model performance." : "Durante a avaliação, o modelo mais recente (treinado {time}) mostrou capturar {recall}% de todos os logins suspeitos (recall), enquanto {precision}% dos logins classificados como suspeitos são realmente suspeitos (precisão). Abaixo você vê uma visualização do desempenho do modelo histórico.",
    "Precision" : "Precisão",
    "Recall" : "Recall",
    "More information ↗" : "Mais Informações ↗",
    "You can get more info by pressing the button which will open %s and show info about the suspicious IP-address." : "Você pode obter mais informações pressionando o botão que irá abrir 1%s e mostrar informações sobre o endereço IP suspeito."
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
